public inbox for pve-devel@lists.proxmox.com
 help / color / mirror / Atom feed
From: Alexandre Derumier <aderumier@odiso.com>
To: pve-devel@lists.proxmox.com
Subject: [pve-devel] [PATCH v5 qemu-server 8/9] vzdump : skip special:cloudinit section
Date: Mon, 16 May 2022 18:07:18 +0200	[thread overview]
Message-ID: <20220516160719.3818057-9-aderumier@odiso.com> (raw)
In-Reply-To: <20220516160719.3818057-1-aderumier@odiso.com>

Signed-off-by: Alexandre Derumier <aderumier@odiso.com>
---
 PVE/VZDump/QemuServer.pm | 5 ++++-
 1 file changed, 4 insertions(+), 1 deletion(-)

diff --git a/PVE/VZDump/QemuServer.pm b/PVE/VZDump/QemuServer.pm
index 7429508..1d38e63 100644
--- a/PVE/VZDump/QemuServer.pm
+++ b/PVE/VZDump/QemuServer.pm
@@ -214,17 +214,20 @@ sub assemble {
 
     my $found_snapshot;
     my $found_pending;
+    my $found_cloudinit;
     while (defined (my $line = <$conffd>)) {
 	next if $line =~ m/^\#vzdump\#/; # just to be sure
 	next if $line =~ m/^\#qmdump\#/; # just to be sure
 	if ($line =~ m/^\[(.*)\]\s*$/) {
 	    if ($1 =~ m/PENDING/i) {
 		$found_pending = 1;
+	    } elsif ($1 =~ m/special:cloudinit/) {
+		$found_cloudinit = 1;
 	    } else {
 		$found_snapshot = 1;
 	    }
 	}
-	next if $found_snapshot || $found_pending; # skip all snapshots and pending changes config data
+	next if $found_snapshot || $found_pending || $found_cloudinit; # skip all snapshots,pending changes and cloudinit config data
 
 	if ($line =~ m/^unused\d+:\s*(\S+)\s*/) {
 	    $self->loginfo("skip unused drive '$1' (not included into backup)");
-- 
2.30.2




  parent reply	other threads:[~2022-05-16 16:08 UTC|newest]

Thread overview: 13+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2022-05-16 16:07 [pve-devel] [PATCH v5 qemu-server 0/9] cloudinit pending behaviour change Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 1/9] cloudinit: add cloudinit section for current generated config Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 2/9] generate cloudinit drive on offline plug Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 3/9] cloudinit: make cloudnit options fastplug Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 4/9] api2: add cloudinit config api Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 5/9] api2: add cloudinit_update Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 6/9] add cloudinit hotplug Alexandre Derumier
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 7/9] api2: qemu : don't display cloudinit value Alexandre Derumier
2022-06-08 10:13   ` Fabian Ebner
2022-05-16 16:07 ` Alexandre Derumier [this message]
2022-05-16 16:07 ` [pve-devel] [PATCH v5 qemu-server 9/9] migration: test targetnode min version for cloudinit section Alexandre Derumier
2022-06-08 10:14   ` Fabian Ebner
2022-06-08 10:14 ` [pve-devel] [PATCH v5 qemu-server 0/9] cloudinit pending behaviour change Fabian Ebner

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20220516160719.3818057-9-aderumier@odiso.com \
    --to=aderumier@odiso.com \
    --cc=pve-devel@lists.proxmox.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox
Service provided by Proxmox Server Solutions GmbH | Privacy | Legal